@@ -35,7 +35,7 @@
  ****************************************************************************/
 
 /*
- * $Id: curses.priv.h,v 1.729 2025/11/01 20:22:42 tom Exp $
+ * $Id: curses.priv.h,v 1.733 2025/11/29 16:17:08 tom Exp $
  *
  *	curses.priv.h
  *
@@ -90,7 +90,7 @@ extern int errno;
 /* Some Windows related defines */
 
 #undef _NC_WINDOWS
-#if (defined(_WIN32) || defined(_WIN64__) || defined(__MSYS__) || defined(__CYGWIN__))
+#if (defined(_WIN32) || defined(_WIN64__) || defined(__MSYS__))
 #define _NC_WINDOWS
 #else
 #undef EXP_WIN32_DRIVER
@@ -1501,12 +1501,16 @@ extern NCURSES_EXPORT_VAR(SIG_ATOMIC_T) _nc_have_sigwinch;
 					NCURSES_OUTC_FUNC (NCURSES_SP_ARGx (int) CharOf(ch)); \
 				    }						    \
 				    break;					    \
-				} else {					    \
+				} else if (PUTC_n > 1 || !is8bits(PUTC_ch)) {	    \
 				    int PUTC_j;					    \
 				    for (PUTC_j = 0; PUTC_j < PUTC_n; ++PUTC_j) {   \
 					TR_PUTC(PUTC_buf[PUTC_j]);		    \
 					NCURSES_OUTC_FUNC (NCURSES_SP_ARGx PUTC_buf[PUTC_j]); \
 				    }						    \
+				} else {					    \
+				    PUTC_buf[0] = (char) PUTC_ch;			    \
+				    TR_PUTC(PUTC_buf[0]);			    \
+				    NCURSES_OUTC_FUNC (NCURSES_SP_ARGx PUTC_buf[0]); \
 				}						    \
 			    }							    \
 			    COUNT_OUTCHARS(PUTC_i);				    \
@@ -1981,7 +1985,7 @@ extern NCURSES_EXPORT(void) _nc_expanded (void);
 	}
 
 #if !NCURSES_WCWIDTH_GRAPHICS
-extern NCURSES_EXPORT(int) _nc_wacs_width(unsigned);
+extern NCURSES_EXPORT(int) _nc_wacs_width(wchar_t);
 #else
 #define _nc_wacs_width(ch) wcwidth(ch)
 #endif
